"""
 ________  ___       __   ________  ________        ___  ___  ________  _______   ________
|\   ____\|\  \     |\  \|\   __  \|\   __  \      |\  \|\  \|\   ____\|\  ___ \ |\   __  \
\ \  \___|\ \  \    \ \  \ \  \|\  \ \  \|\  \     \ \  \\\  \ \  \___|\ \   __/|\ \  \|\  \
 \ \_____  \ \  \  __\ \  \ \   __  \ \   ____\     \ \  \\\  \ \_____  \ \  \_|/_\ \   _  _\
  \|____|\  \ \  \|\__\_\  \ \  \ \  \ \  \___|      \ \  \\\  \|____|\  \ \  \_|\ \ \  \\  \|
    ____\_\  \ \____________\ \__\ \__\ \__\          \ \_______\____\_\  \ \_______\ \__\\ _\
   |\_________\|____________|\|__|\|__|\|__|           \|_______|\_________\|_______|\|__|\|__|
   \|_________|                                                 \|_________|

"""

__title__ = "Django Swap User"
__version__ = "0.2.0"
__author__ = "Artem Innokentiev"
__license__ = "MIT"
__copyright__ = "Copyright 2020 © Artem Innokentiev"

VERSION = __version__

default_app_config = "swap_user.apps.DjangoSwapUser"
